﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;
using System.IO;
using ThinkGeo.MapSuite.DesktopEdition;

namespace ConsoleApplication4
{
    class Program
    {
        static void Main(string[] args)
        {
            LayersCollection layers = new LayersCollection();
            for (int i = 0; i < 2000; i++)
            {
                InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
                inMemoryLayer.InternalFeatures.Add("Polygon", new Feature(BaseShape.CreateShapeFromWellKnownData("POLYGON((10 60,40 70,30 85, 10 60))")));
                inMemoryLayer.InternalFeatures.Add("Multipoint", new Feature(BaseShape.CreateShapeFromWellKnownData("MULTIPOINT(12 20, 30 20,40 20, 12 30, 30 30, 40 30)")));
                inMemoryLayer.InternalFeatures.Add("Line", new Feature(BaseShape.CreateShapeFromWellKnownData("LINESTRING(60 60, 70 70,75 60, 80 70, 85 60,95 80)")));
                inMemoryLayer.InternalFeatures.Add("Rectangle", new Feature(new RectangleShape(65, 30, 90, 15)));

                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.StandardColors.RoyalBlue);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.StandardColors.Blue;
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.FromArgb(200, GeoColor.StandardColors.Red), 5);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Green), 8);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                inMemoryLayer.Open();
                layers.Layers.Add(inMemoryLayer);
            }

            //GeoSerializer geoSerializer = new GeoSerializer();
            //string layersString = geoSerializer.Serialize(layers);

            //FileStream fileStream = new FileStream(@"C:\Serializer.txt", FileMode.Create, FileAccess.Write);
            //StreamWriter streamWriter = new StreamWriter(fileStream);
            //streamWriter.Write(layersString);
            //streamWriter.Close();
            //fileStream.Close();

            //FileStream fs = new FileStream(@"C:\Serializer.txt", FileMode.Open);
            //try
            //{
            //    GlobalSerializer temLayers = (GlobalSerializer)geoSerializer.Deserialize(fs);
            //}
            //catch (Exception)
            //{
            //}

            // Add layers to an overlay on the map
            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add(inMemoryLayer);
            winformsMap.Overlays.Add("Overlay", overlay);

            output = new FileStream(tempFileName, FileMode.Create, FileAccess.Write);
            WritSerializedAll(output, winformsMap.Overlays);

        }

        public static void WriteSerializedAll(FileStream output, Collection<Overlay> overlays)
        {
            GeoSerializer geoSerializer = new GeoSerializer();
            GlobalSerializer globalRecord = new GlobalSerializer();

            foreach (var overlay in overlays)
            {
                globalRecord.FullOverlays.Add(overlay);
            }

            try
            {
                serializer.Serialize(globalRecord, output);
            }
            catch (Exception)
            {
            }
        }
    }



    //we need a class to wrap collection<T> to avoid the collection'1 issue.
    [Serializable]
    class LayersCollection
    {
        public Collection<Layer> Layers = new Collection<Layer>();
    }

    [Serializable]
    class GlobalSerializer
    {

        public Collection<Overlay> FullOverlays { get; private set; }

        public GlobalSerializer()
        {
            FullOverlays = new Collection<Overlay>();
        }
    }
}
